==> apache-answer-1.5.1-src.tar.gz: apache-answer-1.5.1-src/ui/src/stores/index.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import loginSettingStore from './loginSetting';
import seoSettingStore from './seoSetting';
import userCenterStore from './userCenter';
import toastStore from './toast';
import loggedUserInfoStore from './loggedUserInfo';
import siteInfoStore from './siteInfo';
import interfaceStore from './interface';
import brandingStore from './branding';
import pageTagStore from './pageTags';
import customizeStore from './customize';
import themeSettingStore from './themeSetting';
import writeSettingStore from './writeSetting';
import loginToContinueStore from './loginToContinue';
import errorCodeStore from './errorCode';
import sideNavStore from './sideNav';
import commentReplyStore from './commentReply';
import siteLealStore from './siteLegal';

export {
  toastStore,
  loggedUserInfoStore,
  siteInfoStore,
  interfaceStore,
  brandingStore,
  pageTagStore,
  loginSettingStore,
  customizeStore,
  themeSettingStore,
  seoSettingStore,
  loginToContinueStore,
  errorCodeStore,
  userCenterStore,
  sideNavStore,
  commentReplyStore,
  writeSettingStore,
  siteLealStore,
};

==> apache-answer-2.0.0-src.tar.gz: apache-answer-2.0.0-src/ui/src/stores/index.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import loginSettingStore from './loginSetting';
import seoSettingStore from './seoSetting';
import userCenterStore from './userCenter';
import toastStore from './toast';
import loggedUserInfoStore from './loggedUserInfo';
import siteInfoStore from './siteInfo';
import interfaceStore from './interface';
import brandingStore from './branding';
import pageTagStore from './pageTags';
import customizeStore from './customize';
import themeSettingStore from './themeSetting';
import writeSettingStore from './writeSetting';
import loginToContinueStore from './loginToContinue';
import errorCodeStore from './errorCode';
import sideNavStore from './sideNav';
import commentReplyStore from './commentReply';
import siteSecurityStore from './siteSecurity';
import aiControlStore from './aiControl';

export {
  toastStore,
  loggedUserInfoStore,
  siteInfoStore,
  interfaceStore,
  brandingStore,
  pageTagStore,
  loginSettingStore,
  customizeStore,
  themeSettingStore,
  seoSettingStore,
  loginToContinueStore,
  errorCodeStore,
  userCenterStore,
  sideNavStore,
  commentReplyStore,
  writeSettingStore,
  siteSecurityStore,
  aiControlStore,
};
